@@ -399,7 +399,7 @@ class FARequests:
                    count: Optional[int] = None) -> dict:
         """
         :param draw: draw ID, sequental
-        :param sitename: if given, then search dor items only under this site name
+        :param sitename: if given, then search for items only under this site name
         :param start: if given, then the indexed starting task to return from
         :param count: if given, then it is the count of tasks to return
         :return: dict with application/x-www-form-urlencoded fields to use in request for
@@ -489,7 +489,7 @@ class FARequests:
                    count: Optional[int] = None) -> dict:
         """
         :param draw: draw ID, sequental
-        :param sitename: if given, then search dor items only under this site name
+        :param sitename: if given, then search for items only under this site name
         :param start: if given, then the indexed starting task to return from
         :param count: if given, then it is the count of tasks to return
         :return: dict with application/x-www-form-urlencoded fields to use in request for
