@@ -582,3 +582,76 @@ class ImportCellParser:
             raise ImportCellParserException((f"IQF025NFCSPACESDONE: Cell contents type is {type(cellobject.value)}, "
                                              f"string type required"))
         return self._parse_spaces_list(cellobject, ";")
+
+    def IQF026NFCREFORDER(self, cellobject: openpyxl.cell.cell.Cell) -> Union[int, None]:
+        """
+        NFC task cpmpletion reference order
+
+        :param cellobject: openpyxl cell object to parse
+        :return: int order parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        _value = cellobject.value
+        try:
+            _value_int = int(_value)
+        except Exception:
+            raise ImportCellParserException(f"IQF026NFCREFORDER: Wrong value in the cell: {_value}, must be integer")
+        return _value_int
+
+    def IQF027NFCALGORITHM(self, cellobject: openpyxl.cell.cell.Cell) -> Union[str, None]:
+        """
+        Parse algorithm name for NFC automatic task completion
+
+        :param cellobject: openpyxl cell object to parse
+        :return: trimmed & lowercased language
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        _value_stripped_lower = str(cellobject.value).strip().lower()
+        return _value_stripped_lower
+
+    def IQF028TASKDURATION(self, cellobject: openpyxl.cell.cell.Cell) -> Union[timedelta, None]:
+        """
+        Parse task duration into timedelta
+
+        :param cellobject: openpyxl cell object to parse
+        :return: duration timedelta parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        _value = cellobject.value
+        if not isinstance(_value, str):
+            raise ImportCellParserException((f"IQF028TASKDURATION: Cell contents type is {type(_value)}, "
+                                             f"string type required"))
+        _value_split_item = _value.strip()
+        _value_split_item_split = _value_split_item.strip().split(":")
+        if len(_value_split_item_split) != 3:
+            raise ImportCellParserException((f"IQF028TASKDURATION: Wrong cell contents {_value.strip()}, "
+                                             f"must be strictly in format H:M:S"))
+        _output = None
+        _value_h = _value_split_item_split[0].strip()
+        _value_m = _value_split_item_split[1].strip()
+        _value_s = _value_split_item_split[2].strip()
+        if _value_h and _value_m and _value_s:
+            try:
+                _value_h_int = int(_value_h)
+                _value_m_int = int(_value_m)
+                _value_s_int = int(_value_s)
+                if 0 <= _value_h_int <= 23 and 0 <= _value_m_int <= 59 and 0 <= _value_s_int <= 59:
+                    _output = timedelta(hours=_value_h_int, minutes=_value_m_int, seconds=_value_s_int)
+                else:
+                    raise Exception
+            except Exception:
+                raise ImportCellParserException((f"IQF028TASKDURATION: Wrong cell contents {_value.strip()}, "
+                                                 f"must be strictly in format H:M:S"))
+        else:
+            raise ImportCellParserException((f"IQF028TASKDURATION: Wrong cell contents {_value.strip()}, "
+                                             f"must be strictly in format H:M:S"))
+        return _output
